# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
import sys
from datetime import date

if sys.version_info >= (3, 8):
    from importlib import metadata
else:
    import importlib_metadata as metadata

# Include path for Python modules
# NOTE: No longer required since we build documentation
# for a "editable install" of the project.
# sys.path.insert(
#     0,
#     os.path.abspath(os.path.join(os.path.dirname(__file__) or '.', '..',
#                                  '..')))

# -- Project information -----------------------------------------------------

project = 'ByteBlower Test Framework'
copyright = f'{date.today().year!s}, Excentis NV'
author = 'Excentis NV'

# The full version, including alpha/beta/rc tags
release = metadata.version('byteblower-test-framework')

# The short X.Y version
# for example take major/minor
version = '.'.join(release.split('.')[:2])

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.todo',
    'sphinx.ext.imgmath',
    'sphinx.ext.extlinks',
    'sphinx_rtd_theme',
    'sphinx_tabs.tabs',
    'sphinx-jsonschema',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
# language = 'en'  # default
# XXX - By default, build using default English
# language = 'nl'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# html_theme = 'alabaster'
html_theme = 'sphinx_rtd_theme'
html_theme_options = {
    "logo_only": False,
    "style_external_links": True,
    "style_nav_header_background": "#00aeef"
}

# The name of the Pygments (syntax highlighting) style to use.
# XXX - Changes e.g. background on `code-block`s.
pygments_style = 'sphinx'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# If true, “Created using Sphinx” is shown in the HTML footer.
# Default is True.
html_show_sphinx = False

# If true, the reST sources are included in the HTML build as _sources/name.
# The default is True.
html_copy_source = False

# If true (and html_copy_source is true as well), links to the reST sources
# will be added to the sidebar. The default is True.
html_show_sourcelink = False

# A list of paths that contain extra files not directly related to the
# documentation, such as robots.txt or .htaccess. Relative paths are taken
# as relative to the configuration directory. They are copied to the output
# directory. They will overwrite any existing file of the same name.
#
# As these files are not meant to be built, they are automatically excluded
# from source files.
html_extra_path = [
    # NOTE: The extra 'byteblower-test-framework' sub-directory is important
    #       for including this documentation in the ByteBlower Test Framework
    #       "overview" documentation (``byteblower-test-framework-docs``)
    'extra/byteblower-test-framework',
]

# -- Extension configuration -------------------------------------------------

# -- Options for autodoc extension -------------------------------------------

# See Configuration:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#configuration

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autoclass_content
autoclass_content = 'class'  # default
# Other options:
# autoclass_content = 'init'
# autoclass_content = 'both'

# This will separate for example <class>.__init__(self) documentation
# from <class> documentation.
#
# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_class_signature
# autodoc_class_signature = 'mixed'  # default
autodoc_class_signature = 'separated'

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_default_options
# autodoc_default_options = {
#     'special-members': '__init__, __eq__',
#     'show-inheritance': True,
#     'undoc-members': True,
# }

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_typehints
# autodoc_typehints = 'signature'  # default
# autodoc_typehints = 'description'
autodoc_typehints = 'both'

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_typehints_description_target
# autodoc_typehints_description_target = 'all'  # default
# autodoc_typehints_description_target = 'documented'
# Supported since v5.0:
autodoc_typehints_description_target = 'documented_params'

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_type_aliases
# del autodoc_type_aliases  # default
# autodoc_type_aliases = {
#     'Content': 'byteblower_test_framework._analysis.analyseraggregator.Content',
# }

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_typehints_format
# autodoc_typehints_format = 'fully-qualified'  # default < v5.0
autodoc_typehints_format = 'short'  # default since v5.0

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_preserve_defaults
# We keep it to `False` since `const` values are not resolved/documented
# when they are not defined in a public module, no matter whether they
# are "exported" in a public module or not.
autodoc_preserve_defaults = False  # default
# Other options:
# autodoc_preserve_defaults = True

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_inherit_docstrings
# autodoc_inherit_docstrings = True  # default

# -- Options for intersphinx extension ---------------------------------------

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
}

# -- Options for todo extension ----------------------------------------------

# See https://www.sphinx-doc.org/en/master/usage/extensions/todo.html

# If true, `todo` and `todoList` produce output, else they produce nothing.
# todo_include_todos = True  # For development/beta releases!
todo_include_todos = False  # Only for release!

# If this is True, todolist produce output without file path and line, The default is False.
todo_link_only = True  # New in version 1.4

# -- Options for sphinx-tabs extension ----------------------------------------------
# https://sphinx-tabs.readthedocs.io/en/latest/#sphinx-configuration

# By default, tabs can be closed by selecting the open tab. This functionality
# can be disabled using:
sphinx_tabs_disable_tab_closing = True

# By default, the extension loads predefined CSS styles for tabs.
# To disable the CSS from loading, add the following:
# sphinx_tabs_disable_css_loading = True
